# sjtop (WIP)

sjtop is a TUI (Terminal User Interface) for Shioaji using Textual to develop.

NOTE: This project is currently a work in progress

### Installation
```
pip install sjtop
```

### Usage
```
sjtop
```

### Preview

![screenshot](./imgs/sjtop.gif)